@@ -1,4 +1,4 @@
-#ident "$Id: automount.c,v 1.11 2004/03/07 12:17:54 raven Exp $"
+#ident "$Id: automount.c,v 1.15 2004/04/05 13:14:10 raven Exp $"
 /* ----------------------------------------------------------------------- *
  *
  *  automount.c - Linux automounter daemon
@@ -135,21 +135,32 @@ int rmdir_path(const char *path)
 	return 0;
 }
 
-static int umount_ent(const char *root, const char *name)
+static int umount_ent(const char *root, const char *name, const char *type)
 {
 	char path_buf[PATH_MAX];
 	struct stat st;
+	int sav_errno;
+	int is_smbfs = (strcmp(type, "smbfs") == 0);
+	int status;
 	int rv = 0;
 
 	sprintf(path_buf, "%s/%s", root, name);
-	if (!lstat(path_buf, &st)) {
-		if (S_ISDIR(st.st_mode)) {
-			if (st.st_dev != ap.dev) {
-				wait_for_lock();
-				rv = spawnl(LOG_DEBUG, MOUNTED_LOCK, PATH_UMOUNT,
-					    PATH_UMOUNT, path_buf, NULL);
-				unlink(AUTOFS_LOCK);
-			}
+	status =  lstat(path_buf, &st);
+	sav_errno = errno;
+
+	/* EIO appears to correspond to an smb mount that has gone away */
+	if (!status ||
+	    (is_smbfs && (sav_errno == EIO || sav_errno == EBADSLT))) {
+		int umount_ok = 0;
+
+		if (!status && (S_ISDIR(st.st_mode) && (st.st_dev != ap.dev)))
+			umount_ok = 1;
+
+		if (umount_ok || is_smbfs) {
+			wait_for_lock();
+			rv = spawnl(LOG_DEBUG, MOUNTED_LOCK,
+				    PATH_UMOUNT, PATH_UMOUNT, path_buf, NULL);
+			unlink(AUTOFS_LOCK);
 		}
 	}
 	return rv;
@@ -210,7 +221,7 @@ static int rm_unwanted_fn(const char *file, const struct stat *st, int when, voi
 		if (st->st_dev != ap.dev)
 			return 0;
 	} else {
-		DB(syslog(LOG_INFO, "rm_unwanted: %s\n", file));
+		info("rm_unwanted: %s\n", file);
 		if (S_ISDIR(st->st_mode))
 			rmdir(file);
 		else if (!S_ISLNK(st->st_mode) || rmsymlink)
@@ -234,6 +245,7 @@ static int umount_multi(const char *path, int incl)
 	FILE *mtab;
 	struct mntlist {
 		const char *path;
+		const char *fs_type;
 		struct mntlist *next;
 	} *mntlist = NULL, *mptr;
 	size_t pathlen = strlen(path);
@@ -268,9 +280,15 @@ static int umount_multi(const char *path, int incl)
 				break;
 
 		m = alloca(sizeof(*m));
+
 		p = alloca(len + 1);
 		strcpy(p, mnt->mnt_dir);
 		m->path = p;
+
+		p = alloca(strlen(mnt->mnt_type) + 1);
+		strcpy(p, mnt->mnt_type);
+		m->fs_type = p;
+		
 		m->next = *prev;
 		*prev = m;
 	}
@@ -281,7 +299,7 @@ static int umount_multi(const char *path, int incl)
 	left = 0;
 	for (mptr = mntlist; mptr != NULL; mptr = mptr->next) {
 		debug("umount_multi: unmounting dir=%s\n", mptr->path);
-		if (umount_ent("", mptr->path)) {
+		if (umount_ent("", mptr->path, mptr->fs_type)) {
 			left++;
 		}
 	}
@@ -388,8 +406,8 @@ static int mount_autofs(char *path)
 	struct stat st;
 	int len;
 
-	if (ap.state != ST_INIT) {
-		/* This can't happen */
+	if ((ap.state != ST_INIT) || is_mounted(path)) {
+		/* This can happen if an autofs process is already running*/
 		error("mount_autofs: already mounted");
 		return -1;
 	}
