@@ -1,4 +1,4 @@
-#ident "$Id: lookup_program.c,v 1.2 2003/09/29 08:22:35 raven Exp $"
+#ident "$Id: lookup_program.c,v 1.3 2004/01/29 16:01:22 raven Exp $"
 /* ----------------------------------------------------------------------- *
  *   
  *  lookup_program.c - module for Linux automount to access an
@@ -32,12 +32,6 @@
 #define MODULE_LOOKUP
 #include "automount.h"
 
-#ifdef DEBUG
-#define DB(x)           do { x; } while(0)
-#else
-#define DB(x)           do { } while(0)
-#endif
-
 #define MAPFMT_DEFAULT "sun"
 
 #define MODPREFIX "lookup(program): "
@@ -54,25 +48,26 @@ int lookup_init(const char *mapfmt, int argc, const char *const *argv, void **co
 	struct lookup_context *ctxt;
 
 	if (!(*context = ctxt = malloc(sizeof(struct lookup_context)))) {
-		syslog(LOG_CRIT, MODPREFIX "malloc: %m");
+		crit(MODPREFIX "malloc: %m");
 		return 1;
 	}
 
 	if (argc < 1) {
-		syslog(LOG_CRIT, MODPREFIX "No map name");
+		crit(MODPREFIX "No map name");
 		return 1;
 	}
 	ctxt->mapname = argv[0];
 
 	if (ctxt->mapname[0] != '/') {
-		syslog(LOG_CRIT, MODPREFIX "program map %s is not an absolute pathname",
+		crit(MODPREFIX "program map %s is not an absolute pathname",
 		       ctxt->mapname);
 		return 1;
 	}
 
 	if (access(ctxt->mapname, X_OK)) {
-		syslog(LOG_WARNING, MODPREFIX "program map %s missing or not executable",
+		crit(MODPREFIX "program map %s missing or not executable",
 		       ctxt->mapname);
+		return 1;
 	}
 
 	if (!mapfmt)
@@ -102,14 +97,16 @@ int lookup_mount(const char *root, const char *name, int name_len, void *context
 	int ret;
 	int max_fd;
 
-	DB(syslog(LOG_DEBUG, MODPREFIX "looking up %s", name));
+	debug(MODPREFIX "looking up %s", name);
 
-	/* We don't use popen because we don't want to run /bin/sh plus we
-	   want to send stderr to the syslog, and we don't use spawnl()
-	   because we need the pipe hooks */
+	/*
+	 * We don't use popen because we don't want to run /bin/sh plus we
+	 * want to send stderr to the syslog, and we don't use spawnl()
+	 * because we need the pipe hooks
+	 */
 
 	if (pipe(pipefd)) {
-		syslog(LOG_ERR, MODPREFIX "pipe: %m");
+		error(MODPREFIX "pipe: %m");
 		return 1;
 	}
 	if (pipe(epipefd)) {
@@ -124,7 +121,7 @@ int lookup_mount(const char *root, const char *name, int name_len, void *context
 		close(pipefd[1]);
 		close(epipefd[0]);
 		close(epipefd[1]);
-		syslog(LOG_ERR, MODPREFIX "fork: %m");
+		error(MODPREFIX "fork: %m");
 		return 1;
 	} else if (f == 0) {
 		reset_signals();
@@ -181,7 +178,10 @@ int lookup_mount(const char *root, const char *name, int name_len, void *context
 					*mapp = '\0';
 					state = st_done;
 				} else if (mapp - mapent < MAPENT_MAX_LEN - 1) {
-					/* Eat \ quoting \n, otherwise pass it through for the parser */
+					/* 
+					 * Eat \ quoting \n, otherwise pass it
+					 * through for the parser
+					 */
 					if (quoted) {
 						if (ch == '\n')
 							*mapp++ = ' ';
@@ -208,12 +208,12 @@ int lookup_mount(const char *root, const char *name, int name_len, void *context
 			} else if (ch == '\n') {
 				*errp = '\0';
 				if (errbuf[0])
-					syslog(LOG_NOTICE, ">> %s", errbuf);
+					error(">> %s", errbuf);
 				errp = errbuf;
 			} else {
 				if (errp >= &errbuf[1023]) {
 					*errp = '\0';
-					syslog(LOG_NOTICE, ">> %s", errbuf);
+					error(">> %s", errbuf);
 					errp = errbuf;
 				}
 				*(errp++) = ch;
@@ -225,23 +225,23 @@ int lookup_mount(const char *root, const char *name, int name_len, void *context
 		*mapp = '\0';
 	if (errp > errbuf) {
 		*errp = '\0';
-		syslog(LOG_NOTICE, ">> %s", errbuf);
+		error(">> %s", errbuf);
 	}
 
 	close(pipefd[0]);
 	close(epipefd[0]);
 
 	if (waitpid(f, &status, 0) != f) {
-		syslog(LOG_ERR, MODPREFIX "waitpid: %m");
+		error(MODPREFIX "waitpid: %m");
 		return 1;
 	}
 
 	if (mapp == mapent || !WIFEXITED(status) || WEXITSTATUS(status) != 0) {
-		syslog(LOG_NOTICE, MODPREFIX "lookup for %s failed", name);
+		error(MODPREFIX "lookup for %s failed", name);
 		return 1;
 	}
 
-	DB(syslog(LOG_DEBUG, MODPREFIX "%s -> %s", name, mapent));
+	debug(MODPREFIX "%s -> %s", name, mapent);
 
 	ret = ctxt->parse->parse_mount(root, name, name_len,
 				       mapent, ctxt->parse->context);
