@@ -1,4 +1,4 @@
-#ident "$Id: mount_generic.c,v 1.5 2003/10/04 13:20:27 raven Exp $"
+#ident "$Id: mount_generic.c,v 1.7 2004/01/29 16:01:22 raven Exp $"
 /* ----------------------------------------------------------------------- *
  *   
  *  mount_generic.c - module for Linux automountd to mount filesystems
@@ -29,13 +29,8 @@
 #define MODULE_MOUNT
 #include "automount.h"
 
-#ifdef DEBUG
-#define DB(x)           do { x; } while(0)
-#else
-#define DB(x)           do { } while(0)
-#endif
-
 #define MODPREFIX "mount(generic): "
+
 int mount_version = AUTOFS_MOUNT_VERSION;	/* Required by protocol */
 
 extern struct autofs_point ap;
@@ -46,54 +41,60 @@ int mount_init(void **context)
 }
 
 int mount_mount(const char *root, const char *name, int name_len,
-		const char *what, const char *fstype, const char *options, void *context)
+		const char *what, const char *fstype, const char *options,
+		void *context)
 {
 	char *fullpath;
 	int err;
+	int status;
 
 	fullpath = alloca(strlen(root) + name_len + 2);
 	if (!fullpath) {
-		syslog(LOG_ERR, MODPREFIX "alloca: %m");
+		error(MODPREFIX "alloca: %m");
 		return 1;
 	}
 	sprintf(fullpath, "%s/%s", root, name);
 
-	DB(syslog(LOG_DEBUG, MODPREFIX "calling mkdir_path %s", fullpath));
-	if (mkdir_path(fullpath, 0555) && errno != EEXIST) {
-		syslog(LOG_NOTICE, MODPREFIX "mkdir_path %s failed: %m", name);
+	debug(MODPREFIX "calling mkdir_path %s", fullpath);
+
+	if ((status = mkdir_path(fullpath, 0555)) && errno != EEXIST) {
+		error(MODPREFIX "mkdir_path %s failed: %m", name);
 		return 1;
 	}
 
 	if (is_mounted(fullpath)) {
-		syslog(LOG_WARNING, "BUG: %s already mounted", fullpath);
+		error("BUG: %s already mounted", fullpath);
 		return 0;
 	}
 
 	wait_for_lock();
 	if (options) {
-		DB(syslog
-		   (LOG_DEBUG, MODPREFIX "calling mount -t %s " SLOPPY "-o %s %s %s",
-		    fstype, options, what, fullpath));
-		err =
-		    spawnl(LOG_NOTICE, MOUNTED_LOCK, PATH_MOUNT, PATH_MOUNT, "-t", fstype,
-			   SLOPPYOPT "-o", options, what, fullpath, NULL);
+		debug(MODPREFIX "calling mount -t %s " SLOPPY "-o %s %s %s",
+		      fstype, options, what, fullpath);
+
+		err = spawnl(LOG_NOTICE, MOUNTED_LOCK,
+			     PATH_MOUNT, PATH_MOUNT, "-t", fstype,
+			     SLOPPYOPT "-o", options, what, fullpath, NULL);
 	} else {
-		DB(syslog(LOG_DEBUG, MODPREFIX "calling mount -t %s %s %s",
-			  fstype, what, fullpath));
-		err =
-		    spawnl(LOG_NOTICE, MOUNTED_LOCK, PATH_MOUNT, PATH_MOUNT, "-t", fstype,
-			   what, fullpath, NULL);
+		debug(MODPREFIX "calling mount -t %s %s %s",
+		      fstype, what, fullpath);
+		err = spawnl(LOG_NOTICE, MOUNTED_LOCK,
+			     PATH_MOUNT, PATH_MOUNT, "-t", fstype,
+			     what, fullpath, NULL);
 	}
 	unlink(AUTOFS_LOCK);
+
 	if (err) {
-		if (!ap.ghost)
+		if (!ap.ghost || (ap.ghost && !status))
 			rmdir_path(fullpath);
-		syslog(LOG_ERR, MODPREFIX "failed to mount %s (type %s) on %s",
-		       what, fstype, fullpath);
+
+		error(MODPREFIX "failed to mount %s (type %s) on %s",
+		      what, fstype, fullpath);
+
 		return 1;
 	} else {
-		DB(syslog(LOG_DEBUG, MODPREFIX "mounted %s type %s on %s",
-			  what, fstype, fullpath));
+		debug(MODPREFIX "mounted %s type %s on %s",
+		      what, fstype, fullpath);
 		return 0;
 	}
 }
